@@ -1,6 +1,6 @@
 #!/pro/bin/perl
 
-# Copyright (c) 2007-2020 H.Merijn Brand.  All rights reserved.
+# Copyright (c) 2007-2023 H.Merijn Brand.  All rights reserved.
 
 package VCS::SCCS;
 
@@ -11,7 +11,7 @@ use POSIX  qw(mktime);
 use Carp;
 
 use vars qw( $VERSION );
-$VERSION = "0.27";
+$VERSION = "0.28";
 
 ### ###########################################################################
 
@@ -342,6 +342,13 @@ sub body {
 #	join " ", map { sprintf "%s:%02d", $_->[1], $_->[2] } @lvl[1..$#lvl];
 #	}; # v
 
+    my %rseq;
+    my $rr = $r;
+    while ($rr) {
+	$rseq{$rr} = 1;
+	$rr = $self->{delta}{$rr}{prev_rev};
+	}
+
     $self->translate ($r, "");	# Initialize translate hash
 
     my $want = 1;
@@ -394,12 +401,12 @@ sub body {
 	    next;
 	    }
 	if (m/^\cAI\s+(\d+)$/) {
-	    push @lvl, [ $r >= $1 ? 1 : 0, "I", $1 ];
+	    push @lvl, [ $rseq{$1} ? 1 : 0, "I", $1 ];
 	    $want = (grep { $_->[0] == 0 } @lvl) ? 0 : 1;
 	    next;
 	    }
 	if (m/^\cAD\s+(\d+)$/) {
-	    push @lvl, [ $r >= $1 ? 0 : 1, "D", $1 ];
+	    push @lvl, [ $rseq{$1} ? 0 : 1, "D", $1 ];
 	    $want = (grep { $_->[0] == 0 } @lvl) ? 0 : 1;
 	    next;
 	    }
@@ -968,7 +975,7 @@ H.Merijn Brand <h.m.brand@xs4all.nl>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2007-2020 H.Merijn Brand
+Copyright (C) 2007-2023 H.Merijn Brand
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
